@@ -22,12 +22,20 @@ void SonixCam::Analyze(unsigned char *vals, int histo[256], bool ispost)
   if (ispost)
     return;
   i=0;
-  while (!histo[i])
+  int todo=8;
+  while (todo>0)
+  {
+    todo -= histo[i];
     i++;
+  }
   cut_l = i;
   i=255;
-  while (!histo[i])
+  todo=8;
+  while (todo>0)
+  {
+    todo -= histo[i];
     i--;
+  }
   cut_r = i;
 }
 
@@ -71,7 +79,12 @@ void SonixCam::AnalyzeNormalize(unsigned char *vals, int histo[256])
     return; // don't bother
   float step = 255.0/rng;
   for (int i=0; i<w*h*3; i++)
-    vals[i] = (unsigned char) ((vals[i]-cut_l)*step);
+  {
+    int v = (int) ((vals[i]-cut_l)*step);
+    if (v>255) v=255;
+    if (v<0) v=0;
+    vals[i] = (unsigned char) v;
+  }
 }
 
 
